@@ -1,5 +1,5 @@
 from health_check.backends.base import BaseHealthCheckBackend, ServiceUnavailable, ServiceReturnedUnexpectedResult
-from health_check.models import TestModel
+from health_check_db.models import TestModel
 from django.db import DatabaseError, IntegrityError
 from health_check.plugins import plugin_dir
 
@@ -17,4 +17,4 @@ class DjangoDatabaseBackend(BaseHealthCheckBackend):
         except DatabaseError:
             raise ServiceUnavailable("Database error")
 
-plugin_dir.register(DjangoDatabaseBackend)
\ No newline at end of file
+plugin_dir.register(DjangoDatabaseBackend)
